LanguageData class

Constructors

LanguageData({required String langName, required LanguageCode langCode, required RegExp langRegExp})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isoCode → String
Code of the language as test
final
langCode → LanguageCode
Language code and its enum with the suppored languages
final
langName → String
The name of the language
final
langRegExp → RegExp
The RegExp of the language, and this is the key
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited