TextProperties class

Text properties that will auto-change according to the detected language

Constructors

TextProperties({TextStyle? style, TextAlign textAlign = TextAlign.start, TextDirection? fieldDirection})
const

Properties

fieldDirection → TextDirection?
TextDirection of the AutoLangField
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → TextStyle?
TextStyle of the text in the field
final
textAlign → TextAlign
TextAlign of the text in the field
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited